=====
Usage
=====

To use ISLEX pronunciation dictionary accessors in a project::

    import islex

The core classes are loaded from::

    import islex.tokens

And the loading module is found in::

    import islex.load

Data itself is generated from ``/opt/data/islev2.txt`` which is
retrieved from the web in this version.
